==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/BandwidthSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BandwidthSpecBuilder extends BandwidthSpecFluentImpl<BandwidthSpecBuilder> implements VisitableBuilder<BandwidthSpec,BandwidthSpecBuilder>{
  public BandwidthSpecBuilder() {
    this(false);
  }
  public BandwidthSpecBuilder(Boolean validationEnabled) {
    this(new BandwidthSpec(), validationEnabled);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BandwidthSpec(), validationEnabled);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent,BandwidthSpec instance) {
    this(fluent, instance, false);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent,BandwidthSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withBuffer(instance.getBuffer());
      fluent.withLimit(instance.getLimit());
      fluent.withMinburst(instance.getMinburst());
      fluent.withPeakrate(instance.getPeakrate());
      fluent.withRate(instance.getRate());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BandwidthSpecBuilder(BandwidthSpec instance) {
    this(instance,false);
  }
  public BandwidthSpecBuilder(BandwidthSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withBuffer(instance.getBuffer());
      this.withLimit(instance.getLimit());
      this.withMinburst(instance.getMinburst());
      this.withPeakrate(instance.getPeakrate());
      this.withRate(instance.getRate());
    }
    this.validationEnabled = validationEnabled; 
  }
  BandwidthSpecFluent<?> fluent;
  Boolean validationEnabled;
  public BandwidthSpec build() {
    BandwidthSpec buildable = new BandwidthSpec(fluent.getBuffer(),fluent.getLimit(),fluent.getMinburst(),fluent.getPeakrate(),fluent.getRate());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/BandwidthSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BandwidthSpecBuilder extends BandwidthSpecFluent<BandwidthSpecBuilder> implements VisitableBuilder<BandwidthSpec,BandwidthSpecBuilder>{
  public BandwidthSpecBuilder() {
    this(false);
  }
  public BandwidthSpecBuilder(Boolean validationEnabled) {
    this(new BandwidthSpec(), validationEnabled);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BandwidthSpec(), validationEnabled);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent,BandwidthSpec instance) {
    this(fluent, instance, false);
  }
  public BandwidthSpecBuilder(BandwidthSpecFluent<?> fluent,BandwidthSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new BandwidthSpec());

    if (instance != null) {
      fluent.withBuffer(instance.getBuffer());
      fluent.withLimit(instance.getLimit());
      fluent.withMinburst(instance.getMinburst());
      fluent.withPeakrate(instance.getPeakrate());
      fluent.withRate(instance.getRate());
      fluent.withBuffer(instance.getBuffer());
      fluent.withLimit(instance.getLimit());
      fluent.withMinburst(instance.getMinburst());
      fluent.withPeakrate(instance.getPeakrate());
      fluent.withRate(instance.getRate());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BandwidthSpecBuilder(BandwidthSpec instance) {
    this(instance,false);
  }
  public BandwidthSpecBuilder(BandwidthSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new BandwidthSpec());

    if (instance != null) {
      this.withBuffer(instance.getBuffer());
      this.withLimit(instance.getLimit());
      this.withMinburst(instance.getMinburst());
      this.withPeakrate(instance.getPeakrate());
      this.withRate(instance.getRate());
      this.withBuffer(instance.getBuffer());
      this.withLimit(instance.getLimit());
      this.withMinburst(instance.getMinburst());
      this.withPeakrate(instance.getPeakrate());
      this.withRate(instance.getRate());
    }
    this.validationEnabled = validationEnabled; 
  }
  BandwidthSpecFluent<?> fluent;
  Boolean validationEnabled;
  public BandwidthSpec build() {
    BandwidthSpec buildable = new BandwidthSpec(fluent.getBuffer(),fluent.getLimit(),fluent.getMinburst(),fluent.getPeakrate(),fluent.getRate());
    return buildable;
  }
  
}
